@@ -177,6 +177,7 @@ static void DrawButton(FvwmWindow *t, Window win, int w, int h,
       break;
 
     case VectorButton:
+    case DefaultVectorButton:
       if(HAS_MWM_BUTTONS(t) &&
 	 ((stateflags & MWM_DECOR_MAXIMIZE && IS_MAXIMIZED(t)) ||
 	  (stateflags & MWM_DECOR_SHADE && IS_SHADED(t)) ||
@@ -189,60 +190,84 @@ static void DrawButton(FvwmWindow *t, Window win, int w, int h,
 #ifdef MINI_ICONS
     case MiniIconButton:
     case PixmapButton:
-      if (type == PixmapButton)
+    case TiledPixmapButton:
+      if (type == PixmapButton || type == TiledPixmapButton)
 	p = df->u.p;
-      else {
+      else
+      {
 	if (!t->mini_icon)
 	  break;
 	p = t->mini_icon;
       }
 #else
     case PixmapButton:
+    case TiledPixmapButton:
       p = df->u.p;
 #endif /* MINI_ICONS */
       if (DFS_BUTTON_RELIEF(df->style) == DFS_BUTTON_IS_FLAT)
 	border = 0;
       else
 	border = HAS_MWM_BORDER(t) ? 1 : 2;
-      width = w - border * 2; height = h - border * 2;
+      width = w - border * 2;
+      height = h - border * 2;
 
       x = border;
-      if (DFS_H_JUSTIFICATION(df->style) == JUST_RIGHT)
-	x += (int)(width - p->width);
-      else if (DFS_H_JUSTIFICATION(df->style) == JUST_CENTER)
-        /* round up for left buttons, down for right buttons */
-	x += (int)(width - p->width + left1right0) / 2;
-
       y = border;
-      if (DFS_V_JUSTIFICATION(df->style) == JUST_BOTTOM)
+      if (type != TiledPixmapButton)
+      {
+	if (DFS_H_JUSTIFICATION(df->style) == JUST_RIGHT)
+	  x += (int)(width - p->width);
+	else if (DFS_H_JUSTIFICATION(df->style) == JUST_CENTER)
+	  /* round up for left buttons, down for right buttons */
+	  x += (int)(width - p->width + left1right0) / 2;
+	if (DFS_V_JUSTIFICATION(df->style) == JUST_BOTTOM)
 	  y += (int)(height - p->height);
-      else if (DFS_V_JUSTIFICATION(df->style) == JUST_CENTER)
-        /* round up */
-	y += (int)(height - p->height + 1) / 2;
-
-      if (x < border)
-	x = border;
-      if (y < border)
-	y = border;
-      if (width > p->width)
-	width = p->width;
-      if (height > p->height)
-	height = p->height;
-      if (width > w - x - border)
-	width = w - x - border;
-      if (height > h - y - border)
-	height = h - y - border;
+	else if (DFS_V_JUSTIFICATION(df->style) == JUST_CENTER)
+	  /* round up */
+	  y += (int)(height - p->height + 1) / 2;
+	if (x < border)
+	  x = border;
+	if (y < border)
+	  y = border;
+	if (width > p->width)
+	  width = p->width;
+	if (height > p->height)
+	  height = p->height;
+	if (width > w - x - border)
+	  width = w - x - border;
+	if (height > h - y - border)
+	  height = h - y - border;
+      }
 
       XSetClipMask(dpy, Scr.TransMaskGC, p->mask);
-      XSetClipOrigin(dpy, Scr.TransMaskGC, x, y);
-      XCopyArea(dpy, p->picture, win, Scr.TransMaskGC,
-		0, 0, width, height, x, y);
-      break;
+      if (type != TiledPixmapButton)
+      {
+	XSetClipOrigin(dpy, Scr.TransMaskGC, x, y);
+	XCopyArea(dpy, p->picture, win, Scr.TransMaskGC,
+		  0, 0, width, height, x, y);
+      }
+      else
+      {
+	int xi;
+	int yi;
 
-    case TiledPixmapButton:
-      XSetWindowBackgroundPixmap(dpy, win, df->u.p->picture);
-      flush_expose(win);
-      XClearWindow(dpy,win);
+	for (yi = border; yi < height; yi += p->height)
+	{
+	  for (xi = border; xi < width; xi += p->width)
+	  {
+	    int lw = width - x - p->width;
+	    int lh = height - y - p->height;
+
+	    if (lw > p->width)
+	      lw = p->width;
+	    if (lh > p->height)
+	      lh = p->height;
+	    XSetClipOrigin(dpy, Scr.TransMaskGC, xi, yi);
+	    XCopyArea(dpy, p->picture, win, Scr.TransMaskGC,
+		      0, 0, lw, lh, xi, yi);
+	  }
+	}
+      }
       break;
 
     case GradientButton:
@@ -367,7 +392,7 @@ static void RedrawBorder(
 
     xgcv.function = GXnoop;
     xgcv.plane_mask = 0;
-    tgc = XCreateGC(dpy, t->frame, GCFunction | GCPlaneMask, &xgcv);
+    tgc = fvwmlib_XCreateGC(dpy, t->frame, GCFunction | GCPlaneMask, &xgcv);
   }
   /*
    * draw the border; resize handles are InputOnly so draw in the decor_w and
@@ -629,7 +654,7 @@ static void RedrawBorder(
 
       XDrawSegments(dpy, t->decor_w, rgc, marks, i);
 
-      /* shadow marks, reuse the array assuming XDraw doesn't trash it */
+      /* shadow marks, reuse the array (XDrawSegments doesn't trash it) */
       i = 0;
       /* yuck, but j goes 0->1 in the first pass, 1->3 in 2nd */
       j += j + 1;
@@ -1087,8 +1112,8 @@ void SetupTitleBar(FvwmWindow *tmp_win, int w, int h)
   if (ww < buttons * xwc.width)
   {
     xwc.width = ww / buttons;
-    if (xwc.width < 6)
-      xwc.width = 6;
+    if (xwc.width < 1)
+      xwc.width = 1;
     if (xwc.width > tmp_win->title_g.height)
       xwc.width = tmp_win->title_g.height;
     rest = ww - buttons * xwc.width;
@@ -1101,7 +1126,7 @@ void SetupTitleBar(FvwmWindow *tmp_win, int w, int h)
   {
     if (tmp_win->button_w[i] != None)
     {
-      if (xwc.x + tmp_win->title_g.height < w - tmp_win->boundary_width)
+      if (xwc.x + xwc.width < w - tmp_win->boundary_width)
       {
 	XConfigureWindow(dpy, tmp_win->button_w[i], xwcm, &xwc);
 	xwc.x += xwc.width;
@@ -1249,8 +1274,6 @@ void DrawDecorations(
   if (!t)
     return;
   memset(&cd, 0, sizeof(cd));
-  if (HAS_NEVER_FOCUS(t))
-    has_focus = False;
   if (force || expose_win == None)
   {
     is_frame_redraw_allowed = True;
