@@ -683,7 +683,12 @@ static void refresh_window(Window w)
     flush_window_updates();
   }
   XDestroyWindow(dpy, w);
-  XFlush(dpy);
+  XSync(dpy, 0);
+  usleep(1);
+  XSync(dpy, 0);
+  handle_all_expose();
+
+  return;
 }
 
 void refresh_function(F_CMD_ARGS)
@@ -707,6 +712,7 @@ void wait_func(F_CMD_ARGS)
   Window nonewin = None;
   extern FvwmWindow *Tmp_win;
   char *wait_string, *rest;
+  FvwmWindow *s_Tmp_win = Tmp_win;
 
   /* try to get a single token */
   rest = GetNextToken(action, &wait_string);
@@ -778,8 +784,10 @@ void wait_func(F_CMD_ARGS)
   }
   if (redefine_cursor)
     XDefineCursor(dpy, Scr.Root, Scr.FvwmCursors[CRS_ROOT]);
-
+  Tmp_win = s_Tmp_win;
   free(wait_string);
+
+  return;
 }
 
 void quit_func(F_CMD_ARGS)
@@ -1207,14 +1215,11 @@ void LoadDefaultFont(F_CMD_ARGS)
   font = PeekToken(action, &action);
   if (!font)
   {
-    /* Try 'fixed' */
-    font = "";
+    /* Try 'fixed', pass NULL font name */
   }
 
   if (!LoadFvwmFont(dpy, font, &new_font))
   {
-    fvwm_msg(
-      ERR, "SetDefaultFont", "Couldn't load font '%s' or 'fixed'\n", font);
     if (Scr.DefaultFont.font == NULL)
       exit(1);
     else
@@ -1226,6 +1231,8 @@ void LoadDefaultFont(F_CMD_ARGS)
   /* set flags to indicate that the font has changed */
   Scr.flags.do_need_window_update = 1;
   Scr.flags.has_default_font_changed = 1;
+
+  return;
 }
 
 void LoadIconFont(F_CMD_ARGS)
@@ -2107,7 +2114,7 @@ void reset_decor_changes(void)
     decor->flags.has_changed = 0;
     decor->flags.has_title_height_changed = 0;
   }
-  /*!!! must reset individual change flags too */
+  /* todo: must reset individual change flags too */
 #endif
 }
 
@@ -2432,7 +2439,6 @@ static void do_recapture(F_CMD_ARGS, Bool fSingle)
     if (DeferExecution(eventp,&w,&tmp_win,&context, CRS_SELECT,ButtonRelease))
       return;
   }
-  XSync(dpy,0);
   MyXGrabServer(dpy);
   if (fSingle)
     CaptureOneWindow(tmp_win, tmp_win->w, None, None);
@@ -2446,7 +2452,6 @@ static void do_recapture(F_CMD_ARGS, Bool fSingle)
     ButtonPressMask|ButtonReleaseMask|ButtonMotionMask|PointerMotionMask|
     EnterWindowMask|LeaveWindowMask|KeyPressMask|KeyReleaseMask);
   MyXUngrabServer(dpy);
-  XSync(dpy, 0);
 }
 
 void Recapture(F_CMD_ARGS)
