@@ -54,11 +54,12 @@ typedef enum
 } cursor_type;
 
 /* busy cursor bits: just for decoration if BUSYCURSOR is not def */
+#define BUSY_NONE 0
 #define BUSY_READ (1<<0)
-#define BUSY_RECAPTURE (1<<1)
-#define BUSY_WAIT (1<<2)
-#define BUSY_MODULESYNCHRONOUS (1<<3)
-#define BUSY_DYNAMICMENU (1<<4)
+#define BUSY_WAIT (1<<1)
+#define BUSY_MODULESYNCHRONOUS (1<<2)
+#define BUSY_DYNAMICMENU (1<<3)
+#define BUSY_ALL (BUSY_READ|BUSY_WAIT|BUSY_MODULESYNCHRONOUS|BUSY_DYNAMICMENU)
 Cursor *CreateCursors(Display *dpy);
 void CursorStyle(F_CMD_ARGS);
 void setBusyCursor(F_CMD_ARGS);
