@@ -315,6 +315,9 @@ void HandlePropertyNotify(void)
   XTextProperty text_prop;
   Bool OnThisPage = False;
   Bool was_size_inc_set;
+  Bool has_icon_changed = False;
+  Bool has_icon_pixmap_hint_changed = False;
+  Bool has_icon_window_hint_changed = False;
   int old_wmhints_flags;
   int old_width_inc;
   int old_height_inc;
@@ -523,19 +526,51 @@ void HandlePropertyNotify(void)
      * rebuild icon if the client either provides an icon
      * pixmap or window or has reset the hints to `no icon'.
      */
-    if ((Tmp_win->wmhints->flags & (IconPixmapHint|IconWindowHint)) ||
-	(old_wmhints_flags       & (IconPixmapHint|IconWindowHint)))
+    if ((Tmp_win->wmhints->flags & IconPixmapHint) ||
+	(old_wmhints_flags       & IconPixmapHint))
     {
-      if(Tmp_win->icon_bitmap_file == Scr.DefaultIcon)
-	Tmp_win->icon_bitmap_file = NULL;
-      if(!Tmp_win->icon_bitmap_file &&
-	 !(Tmp_win->wmhints->flags&(IconPixmapHint|IconWindowHint)))
+      has_icon_pixmap_hint_changed = True;
+    }
+    if ((Tmp_win->wmhints->flags & IconWindowHint) ||
+	(old_wmhints_flags       & IconWindowHint))
+    {
+      has_icon_window_hint_changed = True;
+    }
+    if (has_icon_window_hint_changed || has_icon_pixmap_hint_changed)
+    {
+      if (ICON_OVERRIDE_MODE(Tmp_win) == ICON_OVERRIDE)
       {
-	Tmp_win->icon_bitmap_file =
-	  (Scr.DefaultIcon) ? strdup(Scr.DefaultIcon) : NULL;
+	has_icon_changed = False;
       }
-      Tmp_win->iconPixmap = (Window)NULL;
-      if(IS_ICONIFIED(Tmp_win))
+      else if (ICON_OVERRIDE_MODE(Tmp_win) == NO_ACTIVE_ICON_OVERRIDE)
+      {
+	if (has_icon_window_hint_changed)
+	  has_icon_changed = True;
+	else
+	has_icon_changed = False;
+      }
+      else
+      {
+	has_icon_changed = True;
+      }
+      if (has_icon_changed)
+      {
+	/* Okay, the icon hint has changed and style options tell us to honour
+	 * this change.  Now let's see if we have to use the application
+	 * provided pixmap or window (if any), the icon file provided by the
+	 * window's style or the default style's icon. */
+	if (Tmp_win->icon_bitmap_file == Scr.DefaultIcon)
+	  Tmp_win->icon_bitmap_file = NULL;
+	if (!Tmp_win->icon_bitmap_file &&
+	    !(Tmp_win->wmhints->flags&(IconPixmapHint|IconWindowHint)))
+	{
+	  Tmp_win->icon_bitmap_file =
+	    (Scr.DefaultIcon) ? Scr.DefaultIcon : NULL;
+	}
+	Tmp_win->iconPixmap = (Window)NULL;
+      }
+
+      if (IS_ICONIFIED(Tmp_win) && has_icon_changed)
       {
 	SET_ICONIFIED(Tmp_win, 0);
 	SET_ICON_UNMAPPED(Tmp_win, 0);
@@ -597,10 +632,7 @@ void HandlePropertyNotify(void)
     old_height_inc = Tmp_win->hints.height_inc;
     old_base_width = Tmp_win->hints.base_width;
     old_base_height = Tmp_win->hints.base_height;
-    /* hack: pause for the tenth of a second to prevent certain race conditions
-     * when xemacs is mapped. Hopefully this delay does not hurt. */
     XSync(dpy, 0);
-    usleep(100000);
     GetWindowSizeHints(Tmp_win);
     if (old_width_inc != Tmp_win->hints.width_inc ||
 	old_height_inc != Tmp_win->hints.height_inc)
@@ -928,8 +960,8 @@ void HandleMapRequestKeepRaised(Window KeepRaised, FvwmWindow *ReuseWin)
 	SetMapStateProp(Tmp_win, NormalState);
 	if (Scr.flags.is_map_desk_in_progress)
 	  do_grab_focus = False;
-	if (!OnThisPage)
-	  do_grab_focus = True;
+	else if (!OnThisPage)
+	  do_grab_focus = False;
 	else if (DO_GRAB_FOCUS(Tmp_win) &&
 		 (!IS_TRANSIENT(Tmp_win) || Tmp_win->transientfor == Scr.Root))
 	{
@@ -947,7 +979,7 @@ void HandleMapRequestKeepRaised(Window KeepRaised, FvwmWindow *ReuseWin)
 				&JunkDepth)))
 	{
 	  /* Gee, the transientfor does not exist! These evil application
-	   * programmers must hate us a lot. */
+	   * programmers must hate us a lot ;-) */
 	  Tmp_win->transientfor = Scr.Root;
 	  do_grab_focus = True;
 	}
@@ -991,7 +1023,7 @@ void HandleMapRequestKeepRaised(Window KeepRaised, FvwmWindow *ReuseWin)
 	isIconifiedByParent = False;
 	SET_ICONIFIED_BY_PARENT(Tmp_win, 1);
       }
-      if (Tmp_win->wmhints)
+      if (USE_ICON_POSITION_HINT(Tmp_win) && Tmp_win->wmhints)
       {
 	Iconify(Tmp_win, Tmp_win->wmhints->icon_x,
 		Tmp_win->wmhints->icon_y);
@@ -2866,6 +2898,22 @@ int discard_events(long event_mask)
   return count;
 }
 
+/* This function discards all queued up ButtonPress, ButtonRelease and
+ * ButtonMotion events. */
+int discard_window_events(Window w, long event_mask)
+{
+  XEvent e;
+  int count;
+
+  XSync(dpy, 0);
+  for (count = 0; XCheckWindowEvent(dpy, w, event_mask, &e); count++)
+  {
+    StashEventTime(&e);
+  }
+
+  return count;
+}
+
 /* Similar function for certain types of PropertyNotify. */
 static int flush_property_notify(Atom atom, Window w)
 {
