@@ -226,6 +226,11 @@ typedef struct
     unsigned has_no_icon_title : 1;
     unsigned has_override_size : 1;
     unsigned has_stippled_title : 1;
+    unsigned icon_override : 2;
+#define NO_ACTIVE_ICON_OVERRIDE 0
+#define ICON_OVERRIDE           1
+#define NO_ICON_OVERRIDE        2
+#define ICON_OVERRIDE_MASK      3
     unsigned is_fixed : 1;
     unsigned is_icon_sticky : 1;
     unsigned is_icon_suppressed : 1;
@@ -261,6 +266,7 @@ typedef struct
   unsigned is_icon_shaped : 1; /* is the icon shaped? */
   unsigned is_icon_unmapped : 1; /* was the icon unmapped, even though the
 				  * window is still iconified (Transients) */
+  unsigned is_in_transient_subtree : 1; /* temporary flag used in stack.c */
   unsigned is_mapped : 1; /* is it mapped? */
   unsigned is_map_pending : 1; /* Sent an XMapWindow, but didn't receive a
 				* MapNotify yet.*/
@@ -271,6 +277,8 @@ typedef struct
   unsigned is_partially_visible : 1; /* is the window partially visible */
   unsigned is_pixmap_ours : 1; /* is the icon pixmap ours to free? */
   unsigned is_placed_wb3 : 1;
+  unsigned is_scheduled_for_destroy : 1; /* mark window to be destroyed after
+					  * last complex func has finished. */
   unsigned is_scheduled_for_raise : 1; /* mark window to be raised after
 					* function execution. */
   unsigned is_size_inc_set : 1;
@@ -354,11 +362,6 @@ typedef struct
   unsigned active_placement_honors_starts_on_page : 1;
   unsigned capture_honors_starts_on_page : 1;
   unsigned recapture_honors_starts_on_page : 1;
-  unsigned icon_override : 2;
-#define NO_ACTIVE_ICON_OVERRIDE 0
-#define ICON_OVERRIDE           1
-#define NO_ICON_OVERRIDE        2
-#define ICON_OVERRIDE_MASK      3
 } style_flags;
 
 /* only style.c and add_window.c are allowed to access this struct!! */
@@ -501,6 +504,8 @@ typedef struct FvwmWindow
   int max_window_height;
   int shade_anim_steps;
   unsigned char grabbed_buttons;
+
+  void *pscratch;             /* multi purpose scratch pointer */
 } FvwmWindow;
 
 /* include this down here because FvwmWindows must be defined when including
