@@ -78,6 +78,7 @@ static Bool sent_save_done = 0;
 
 static int num_match = 0;
 static Match *matches = NULL;
+static Bool does_file_version_match = False;
 
 extern Bool Restarting;
 
@@ -165,8 +166,12 @@ LoadGlobalState(char *filename)
   /* char s2[256]; */
   int i1, i2, i3, i4, i5, i6;
 
-  if (!filename || !*filename) return;
-  if ((f = fopen(filename, "r")) == NULL) return;
+  if (!does_file_version_match)
+    return;
+  if (!filename || !*filename)
+    return;
+  if ((f = fopen(filename, "r")) == NULL)
+    return;
 
   while (fgets(s, sizeof(s), f))
   {
@@ -200,6 +205,7 @@ LoadGlobalState(char *filename)
     */
       MoveViewport(i1, i2, True);
     }
+#if 0
     /* migo (08-Dec-1999): we don't want to eliminate .fvwm2rc for now */
     else if (/*!Restarting*/ 0)
     {
@@ -244,6 +250,7 @@ LoadGlobalState(char *filename)
         Scr.gs.EmulateWIN = i2;
       }
     }
+#endif
   }
   fclose(f);
 }
@@ -299,6 +306,56 @@ GetClientID(Window window)
   return client_id;
 }
 
+/*
+**  Verify the current fvwm version with the version that stroed the state file.
+**  No state will be restored if versions don't match.
+*/
+static Bool VerifyVersionInfo(char *filename)
+{
+  FILE               *f;
+  char                s[4096], s1[4096];
+
+  if (!filename || !*filename)
+    return False;
+  if ((f = fopen(filename, "r")) == NULL)
+    return False;
+
+  while (fgets(s, sizeof(s), f))
+  {
+    sscanf(s, "%4000s", s1);
+    if (!strcmp(s1, "[FVWM_VERSION]"))
+    {
+      char v[256];
+
+      sprintf(v, "%s,%s", VERSION, __DATE__);
+      sscanf(s, "%*s %[^\n]", s1);
+      if (strcmp(s1, v) == 0)
+      {
+	does_file_version_match = True;
+      }
+      else
+      {
+	fvwm_msg(
+	  ERR, "VerifyVersionInfo",
+	  "State file version (%s) does not match fvwm version (%s)\n"
+	  "State file will be ignored", s1, v);
+	break;
+      }
+    }
+  }
+  fclose(f);
+
+  return does_file_version_match;
+}
+
+static int
+SaveVersionInfo(FILE *f)
+{
+  fprintf(f, "[FVWM_VERSION] %s,%s\n", VERSION, __DATE__);
+
+  return 1;
+}
+
 static int
 SaveWindowStates(FILE *f)
 {
@@ -388,6 +445,13 @@ SaveWindowStates(FILE *f)
   return 1;
 }
 
+void
+DisableSM(void)
+{
+  num_match = 0;
+  return;
+}
+
 void
 LoadWindowStates(char *filename)
 {
@@ -396,6 +460,9 @@ LoadWindowStates(char *filename)
   int i, pos, pos1;
   unsigned long w;
 
+  if (!VerifyVersionInfo(filename))
+    return;
+
   if (!filename || !*filename)
     return;
 
@@ -644,6 +711,8 @@ MatchWinToSM(FvwmWindow *ewin, int *do_shade, int *do_max)
 {
   int i;
 
+  if (!does_file_version_match)
+    return False;
   for (i = 0; i < num_match; i++)
   {
     if (!matches[i].used && matchWin(ewin, &matches[i]))
@@ -701,7 +770,7 @@ MatchWinToSM(FvwmWindow *ewin, int *do_shade, int *do_max)
       ewin->max_offset.x = matches[i].max_x_offset;
       ewin->max_offset.y = matches[i].max_y_offset;
       SET_STICKY(ewin, IS_STICKY(&(matches[i])));
-      ewin->Desk = matches[i].desktop;
+      ewin->Desk = (IS_STICKY(ewin)) ? Scr.CurrentDesk : matches[i].desktop;
       set_layer(ewin, matches[i].layer);
 
       /* this is not enough to fight fvwms attempts to
@@ -744,7 +813,7 @@ static int saveStateFile(char *filename)
 #endif
 
   success = doPreserveState?
-    SaveWindowStates(f) && SaveGlobalState(f):
+    SaveVersionInfo(f) && SaveWindowStates(f) && SaveGlobalState(f):
     1;
   doPreserveState = True;
   if (fclose(f) != 0)
