@@ -91,18 +91,18 @@
           (fw)->flags.common.s.has_bottom_title = !!(x)
 #define SETM_HAS_BOTTOM_TITLE(fw,x) \
           (fw)->flag_mask.common.s.has_bottom_title = !!(x)
-#define HAS_GRABBED_BUTTONS(fw) \
-          ((fw)->flags.common.has_grabbed_buttons)
-#define SET_GRABBED_BUTTONS(fw,x) \
-          (fw)->flags.common.has_grabbed_buttons = !!(x)
-#define SETM_GRABBED_BUTTONS(fw,x) \
-          (fw)->flag_mask.common.has_grabbed_buttons = !!(x)
 #define HAS_STIPPLED_TITLE(fw)  \
           ((fw)->flags.common.s.has_stippled_title)
 #define SET_HAS_STIPPLED_TITLE(fw,x) \
           (fw)->flags.common.s.has_stippled_title = !!(x)
 #define SETM_HAS_STIPPLED_TITLE(fw,x) \
           (fw)->flag_mask.common.s.has_stippled_title = !!(x)
+#define ICON_OVERRIDE_MODE(fw)  \
+          ((fw)->flags.common.s.icon_override)
+#define SET_ICON_OVERRIDE_MODE(fw,x)  \
+          (fw)->flags.common.s.icon_override = !!(x)
+#define SETM_ICON_OVERRIDE_MODE(fw,x) \
+          (fw)->flag_mask.common.s.icon_override = !!(x)
 #define IS_ICON_STICKY(fw)     ((fw)->flags.common.s.is_icon_sticky)
 #define SET_ICON_STICKY(fw,x)  (fw)->flags.common.s.is_icon_sticky = !!(x)
 #define SETM_ICON_STICKY(fw,x) \
@@ -221,6 +221,9 @@
                                (fw)->flags.is_icon_unmapped = !!(x)
 #define SETM_ICON_UNMAPPED(fw,x) \
                                (fw)->flag_mask.is_icon_unmapped = !!(x)
+#define IS_IN_TRANSIENT_SUBTREE(fw) ((fw)->flags.is_in_transient_subtree)
+#define SET_IN_TRANSIENT_SUBTREE(fw,x) \
+          (fw)->flags.is_in_transient_subtree = !!(x)
 #define IS_MAP_PENDING(fw)     ((fw)->flags.is_map_pending)
 #define SET_MAP_PENDING(fw,x)  (fw)->flags.is_map_pending = !!(x)
 #define SETM_MAP_PENDING(fw,x) (fw)->flag_mask.is_map_pending = !!(x)
@@ -236,6 +239,9 @@
 #define IS_PLACED_WB3(fw)      ((fw)->flags.is_placed_wb3)
 #define SET_PLACED_WB3(fw,x)   (fw)->flags.is_placed_wb3 = !!(x)
 #define SETM_PLACED_WB3(fw,x)  (fw)->flag_mask.is_placed_wb3 = !!(x)
+#define IS_SCHEDULED_FOR_DESTROY(fw)    ((fw)->flags.is_scheduled_for_destroy)
+#define SET_SCHEDULED_FOR_DESTROY(fw,x) \
+          (fw)->flags.is_scheduled_for_destroy = !!(x)
 #define IS_SCHEDULED_FOR_RAISE(fw)    ((fw)->flags.is_scheduled_for_raise)
 #define SET_SCHEDULED_FOR_RAISE(fw,x) (fw)->flags.is_scheduled_for_raise = !!(x)
 #define IS_SHADED(fw)          ((fw)->flags.is_window_shaded)
@@ -298,7 +304,18 @@
           (fw)->flags.does_wm_take_focus = !!(x)
 #define SETM_WM_TAKES_FOCUS(fw,x) \
           (fw)->flag_mask.does_wm_take_focus = !!(x)
-
+#define USING_DEFAULT_WINDOW_FONT(fw) \
+          ((fw)->flags.using_default_window_font)
+#define SET_USING_DEFAULT_WINDOW_FONT(fw,x) \
+          (fw)->flags.using_default_window_font = !!(x)
+#define SETM_USING_DEFAULT_WINDOW_FONT(fw,x) \
+          (fw)->flag_mask.using_default_window_font = !!(x)
+#define USING_DEFAULT_ICON_FONT(fw) \
+          ((fw)->flags.using_default_icon_font)
+#define SET_USING_DEFAULT_ICON_FONT(fw,x) \
+          (fw)->flags.using_default_icon_font = !!(x)
+#define SETM_USING_DEFAULT_ICON_FONT(fw,x) \
+          (fw)->flag_mask.using_default_icon_font = !!(x)
 
 
 #endif /* _WINDOW_FLAGS_ */
