@@ -98,15 +98,21 @@ char *SkipQuote(char *s, const char *qlong, const char *qstart,
  * malloc'd area just like GetNextToken. Quotes are not removed from the
  * returned string. The returned string is stored in *sout, the return value
  * of this call is a pointer to the first character after the delimiter or
- * to the terminating '\0'. Quoting is handled like in SkipQuote. */
+ * to the terminating '\0'. Quoting is handled like in SkipQuote. If sin is
+ * NULL, the function returns NULL in *sout. */
 char *GetQuotedString(char *sin, char **sout, const char *delims,
 		      const char *qlong, const char *qstart, const char *qend)
 {
   char *t = sin;
   unsigned int len;
 
-  if (!sout || !sin)
+  if (!sout)
     return NULL;
+  if (!sin)
+  {
+    *sout = NULL;
+    return NULL;
+  }
 
   while (*t && !strchr(delims, *t))
     t = SkipQuote(t, qlong, qstart, qend);
@@ -124,7 +130,7 @@ char *GetQuotedString(char *sin, char **sout, const char *delims,
  * neither a whitespace character nor contained in the string 'spaces'. snum
  * is the number of characters in 'spaces'. You must not pass a NULL pointer
  * in indata. */
-static char *SkipSpaces(char *indata, char *spaces, int snum)
+char *SkipSpaces(char *indata, char *spaces, int snum)
 {
   while (*indata != 0 && (isspace((unsigned char)*indata) ||
 			  (snum && strchr(spaces, *indata))))
@@ -140,39 +146,60 @@ static char *SkipSpaces(char *indata, char *spaces, int snum)
 static char *CopyToken(char *src, char *dest, char *spaces, int snum,
 		       char *delims, int dnum, char *out_delim)
 {
+  int len = 0;
+
   while ( (*src != 0) && !(isspace((unsigned char)*src) ||
 			   (snum && strchr(spaces, *src)) ||
 			   (dnum && strchr(delims, *src))))
+  {
+    /* Check for qouted text */
+    if (IsQuote(*src))
     {
-      /* Check for qouted text */
-      if (IsQuote(*src))
-	{
-	  char c = *src;
+      char c = *src;
 
+      src++;
+      while((*src != c)&&(*src != 0))
+      {
+	if((*src == '\\' && *(src+1) != 0))
+	  /* Skip over backslashes */
 	  src++;
-	  while((*src != c)&&(*src != 0))
-	    {
-	      if((*src == '\\' && *(src+1) != 0))
-		/* Skip over backslashes */
-		src++;
-	      *(dest++) = *(src++);
-	    }
-	  if(*src == c)
-	    src++;
-	}
-      else
+	if (len < MAX_TOKEN_LENGTH - 1)
 	{
-	  if((*src == '\\' && *(src+1) != 0))
-	    /* Skip over backslashes */
-	    src++;
+	  len++;
 	  *(dest++) = *(src++);
 	}
+	else
+	{
+	  /* token too long, just skip rest of token */
+	  src++;
+	}
+      }
+      if(*src == c)
+	src++;
     }
+    else
+    {
+      if((*src == '\\' && *(src+1) != 0))
+	/* Skip over backslashes */
+	src++;
+      if (len < MAX_TOKEN_LENGTH - 1)
+      {
+	len++;
+	*(dest++) = *(src++);
+      }
+      else
+      {
+	/* token too long, just skip rest of token */
+	src++;
+      }
+    }
+  }
   if (out_delim)
     *out_delim = *src;
   *dest = 0;
   if (*src != 0)
     src++;
+
   return src;
 }
 
@@ -201,13 +228,13 @@ char *DoPeekToken(char *indata, char **token, char *spaces, char *delims,
 
   snum = (spaces) ? strlen(spaces) : 0;
   dnum = (delims) ? strlen(delims) : 0;
-  if(indata == NULL)
-    {
-      if (out_delim)
-	*out_delim = '\0';
-      *token = NULL;
-      return NULL;
-    }
+  if (indata == NULL)
+  {
+    if (out_delim)
+      *out_delim = '\0';
+    *token = NULL;
+    return NULL;
+  }
   indata = SkipSpaces(indata, spaces, snum);
   end = CopyToken(indata, tmptok, spaces, snum, delims, dnum, out_delim);
 
