@@ -243,13 +243,22 @@ int main(int argc, char **argv)
   /* Check for an alias */
   if (argc >= opt_num + 1)
     {
-      if (strspn(argv[opt_num], "0123456789") != strlen(argv[opt_num]) &&
-	  !StrEquals(argv[opt_num], "*"))
+      char *s;
+
+      if (!StrEquals(argv[opt_num], "*"))
+      {
+	for (s = argv[opt_num]; *s; s++)
 	{
-	  free(MyName);
-	  MyName=strdup(argv[opt_num]);
-	  opt_num++;
+	  if (!isdigit(*s) &&
+	      (*s != '-' || s != argv[opt_num] || *(s+1) == 0))
+	  {
+	    free(MyName);
+	    MyName=strdup(argv[opt_num]);
+	    opt_num++;
+	    break;
+	  }
 	}
+      }
     }
 
   if (argc < opt_num + 1)
@@ -673,7 +682,7 @@ void list_configure(unsigned long *body)
     ChangeDeskForWindow(t, cfgpacket->desk);
   }
   else
-    MoveResizePagerView(t);
+    MoveResizePagerView(t, False);
 }
 
 /***********************************************************************
@@ -781,7 +790,7 @@ void list_new_page(unsigned long *body)
     Scr.VHeight = Scr.VyMax + Scr.MyDisplayHeight;
     ReConfigure();
   }
-  MovePage();
+  MovePage(False);
   MoveStickyWindows();
   Hilight(FocusWin,True);
 }
@@ -922,7 +931,7 @@ void list_new_desk(unsigned long *body)
     XClearWindow(dpy, Desks[0].title_w);
   } /* if (fAlwaysCurrentDesk && oldDesk != Scr.CurrentDesk) */
 
-  MovePage();
+  MovePage(True);
   DrawGrid(oldDesk - desk1,1);
   DrawGrid(Scr.CurrentDesk - desk1,1);
   MoveStickyWindows();
@@ -1033,7 +1042,7 @@ void list_iconify(unsigned long *body)
       if ( t->w == Scr.Pager_w )
 	ShowBalloons = ShowIconBalloons;
 
-      MoveResizePagerView(t);
+      MoveResizePagerView(t, True);
     }
 }
 
@@ -1076,7 +1085,7 @@ void list_deiconify(unsigned long *body)
       if ( t->w == Scr.Pager_w )
 	ShowBalloons = ShowPagerBalloons;
 
-      MoveResizePagerView(t);
+      MoveResizePagerView(t, True);
     }
 }
 
